@@ -17,8 +17,8 @@ use super::{
 };
 use crate::app::{models::StatefulTable, ActiveBlock, App};
 
-static DESCRIBE_AND_YAML_HINT: &str = "| describe <d> | yaml <y>";
-static DESCRIBE_YAML_AND_ESC_HINT: &str = "| describe <d> | yaml <y> | back to menu <esc>";
+static DESCRIBE_AND_YAML_HINT: &str = "| describe <d> | yaml <y> ";
+static DESCRIBE_YAML_AND_ESC_HINT: &str = "| describe <d> | yaml <y> | back to menu <esc> ";
 static COPY_HINT: &str = "| copy <c>";
 static NODES_TITLE: &str = "Nodes";
 static PODS_TITLE: &str = "Pods";
@@ -35,13 +35,13 @@ static RPL_CTRL_TITLE: &str = "ReplicationControllers";
 static DESCRIBE_ACTIVE: &str = "-> Describe ";
 static YAML_ACTIVE: &str = "-> YAML ";
 
-pub fn draw_resource_tabs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+pub fn draw_resource_tabs_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let chunks =
     vertical_chunks_with_margin(vec![Constraint::Length(2), Constraint::Min(0)], area, 1);
 
-  let mut block = layout_block_default("Resources");
+  let mut block = layout_block_default(" Resources ");
   if app.get_current_route().active_block != ActiveBlock::Namespaces {
-    block = block.style(style_secondary())
+    block = block.style(style_secondary(app.light_theme))
   }
 
   let titles = app
@@ -52,7 +52,7 @@ pub fn draw_resource_tabs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, are
     .collect();
   let tabs = Tabs::new(titles)
     .block(block)
-    .highlight_style(style_secondary())
+    .highlight_style(style_secondary(app.light_theme))
     .select(app.context_tabs.index);
 
   f.render_widget(tabs, area);
@@ -74,7 +74,7 @@ pub fn draw_resource_tabs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, are
 }
 
 /// more resources tab
-fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   match block {
     // ActiveBlock::More => draw_menu(f, app, area),
     ActiveBlock::CronJobs => draw_cronjobs_tab(block, f, app, area),
@@ -98,10 +98,10 @@ fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App, ar
 }
 
 /// more resources menu
-fn draw_menu<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_menu<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let area = centered_rect(50, 15, area);
 
-  let items: Vec<ListItem> = app
+  let items: Vec<ListItem<'_>> = app
     .more_resources_menu
     .items
     .iter()
@@ -109,7 +109,7 @@ fn draw_menu<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
     .collect();
   f.render_stateful_widget(
     List::new(items)
-      .block(layout_block_default("Select Resource"))
+      .block(layout_block_default(" Select Resource "))
       .highlight_style(style_highlight())
       .highlight_symbol(HIGHLIGHT),
     area,
@@ -127,7 +127,7 @@ macro_rules! draw_resource_tab {
         $area,
         title_with_dual_style(
           get_resource_title($app, $title, get_describe_active($block), $res.items.len()),
-          format!("{} | {} <esc>", COPY_HINT, $title),
+          format!("{} | {} <esc> ", COPY_HINT, $title),
           $app.light_theme,
         ),
       ),
@@ -137,7 +137,7 @@ macro_rules! draw_resource_tab {
   };
 }
 
-fn draw_pods_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_pods_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   match block {
     ActiveBlock::Containers => draw_containers_block(f, app, area),
     ActiveBlock::Describe | ActiveBlock::Yaml => draw_describe_block(
@@ -151,7 +151,7 @@ fn draw_pods_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App
           get_describe_active(block),
           app.data.pods.items.len(),
         ),
-        format!("{} | {} <esc>", COPY_HINT, PODS_TITLE),
+        format!("{} | {} <esc> ", COPY_HINT, PODS_TITLE),
         app.light_theme,
       ),
     ),
@@ -161,7 +161,7 @@ fn draw_pods_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App
   };
 }
 
-fn draw_pods_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_pods_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, PODS_TITLE, "", app.data.pods.items.len());
 
   draw_resource_block(
@@ -182,7 +182,7 @@ fn draw_pods_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
       ],
     },
     |c| {
-      let style = get_resource_row_style(c.status.as_str(), c.ready);
+      let style = get_resource_row_style(c.status.as_str(), c.ready, app.light_theme);
       Row::new(vec![
         Cell::from(c.namespace.to_owned()),
         Cell::from(c.name.to_owned()),
@@ -198,7 +198,7 @@ fn draw_pods_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
   );
 }
 
-fn draw_containers_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_containers_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_container_title(app, app.data.containers.items.len(), "");
 
   draw_resource_block(
@@ -206,7 +206,7 @@ fn draw_containers_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect
     area,
     ResourceTableProps {
       title,
-      inline_help: format!("| Logs <enter> | {} <esc>", PODS_TITLE),
+      inline_help: format!("| Logs <enter> | {} <esc> ", PODS_TITLE),
       resource: &mut app.data.containers,
       table_headers: vec![
         "Name",
@@ -232,7 +232,7 @@ fn draw_containers_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect
       ],
     },
     |c| {
-      let style = get_resource_row_style(c.status.as_str(), (0, 0));
+      let style = get_resource_row_style(c.status.as_str(), (0, 0), app.light_theme);
       Row::new(vec![
         Cell::from(c.name.to_owned()),
         Cell::from(c.image.to_owned()),
@@ -251,7 +251,7 @@ fn draw_containers_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect
   );
 }
 
-fn draw_logs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_logs_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let selected_container = app.data.selected.container.clone();
   let container_name = selected_container.unwrap_or_default();
 
@@ -261,23 +261,26 @@ fn draw_logs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
       app.data.containers.items.len(),
       format!("-> Logs ({}) ", container_name),
     ),
-    "| copy <c> | Containers <esc>".into(),
+    "| copy <c> | Containers <esc> ".into(),
     app.light_theme,
   );
 
   let block = layout_block_top_border(title);
 
   if container_name == app.data.logs.id {
-    app
-      .data
-      .logs
-      .render_list(f, area, block, style_primary(), app.log_auto_scroll);
+    app.data.logs.render_list(
+      f,
+      area,
+      block,
+      style_primary(app.light_theme),
+      app.log_auto_scroll,
+    );
   } else {
-    loading(f, block, area, app.is_loading);
+    loading(f, block, area, app.is_loading, app.light_theme);
   }
 }
 
-fn draw_nodes_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_nodes_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   match block {
     ActiveBlock::Describe | ActiveBlock::Yaml => draw_describe_block(
       f,
@@ -285,7 +288,7 @@ fn draw_nodes_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut Ap
       area,
       title_with_dual_style(
         get_node_title(app, get_describe_active(block)),
-        format!("{} | {} <esc>", COPY_HINT, NODES_TITLE),
+        format!("{} | {} <esc> ", COPY_HINT, NODES_TITLE),
         app.light_theme,
       ),
     ),
@@ -294,7 +297,7 @@ fn draw_nodes_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut Ap
   };
 }
 
-fn draw_nodes_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_nodes_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_node_title(app, "");
 
   draw_resource_block(
@@ -325,9 +328,9 @@ fn draw_nodes_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
     },
     |c| {
       let style = if c.status != "Ready" {
-        style_failure()
+        style_failure(app.light_theme)
       } else {
-        style_primary()
+        style_primary(app.light_theme)
       };
       Row::new(vec![
         Cell::from(c.name.to_owned()),
@@ -350,7 +353,12 @@ fn draw_nodes_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
   );
 }
 
-fn draw_services_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_services_tab<B: Backend>(
+  block: ActiveBlock,
+  f: &mut Frame<'_, B>,
+  app: &mut App,
+  area: Rect,
+) {
   draw_resource_tab!(
     SERVICES_TITLE,
     block,
@@ -363,7 +371,7 @@ fn draw_services_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut
   );
 }
 
-fn draw_services_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_services_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, SERVICES_TITLE, "", app.data.services.items.len());
 
   draw_resource_block(
@@ -402,7 +410,7 @@ fn draw_services_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect)
         Cell::from(c.ports.to_owned()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
@@ -411,7 +419,7 @@ fn draw_services_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect)
 
 fn draw_config_maps_tab<B: Backend>(
   block: ActiveBlock,
-  f: &mut Frame<B>,
+  f: &mut Frame<'_, B>,
   app: &mut App,
   area: Rect,
 ) {
@@ -427,7 +435,7 @@ fn draw_config_maps_tab<B: Backend>(
   );
 }
 
-fn draw_config_maps_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_config_maps_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, CONFIG_MAPS_TITLE, "", app.data.config_maps.items.len());
 
   draw_resource_block(
@@ -452,7 +460,7 @@ fn draw_config_maps_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rec
         Cell::from(c.data.len().to_string()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
@@ -461,7 +469,7 @@ fn draw_config_maps_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rec
 
 fn draw_stateful_sets_tab<B: Backend>(
   block: ActiveBlock,
-  f: &mut Frame<B>,
+  f: &mut Frame<'_, B>,
   app: &mut App,
   area: Rect,
 ) {
@@ -477,7 +485,7 @@ fn draw_stateful_sets_tab<B: Backend>(
   );
 }
 
-fn draw_stateful_sets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_stateful_sets_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, STFS_TITLE, "", app.data.stateful_sets.items.len());
 
   draw_resource_block(
@@ -504,7 +512,7 @@ fn draw_stateful_sets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: R
         Cell::from(c.service.to_owned()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
@@ -513,7 +521,7 @@ fn draw_stateful_sets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: R
 
 fn draw_replica_sets_tab<B: Backend>(
   block: ActiveBlock,
-  f: &mut Frame<B>,
+  f: &mut Frame<'_, B>,
   app: &mut App,
   area: Rect,
 ) {
@@ -529,7 +537,7 @@ fn draw_replica_sets_tab<B: Backend>(
   );
 }
 
-fn draw_replica_sets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_replica_sets_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(
     app,
     REPLICA_SETS_TITLE,
@@ -563,7 +571,7 @@ fn draw_replica_sets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Re
         Cell::from(c.ready.to_string()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
@@ -572,7 +580,7 @@ fn draw_replica_sets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Re
 
 fn draw_deployments_tab<B: Backend>(
   block: ActiveBlock,
-  f: &mut Frame<B>,
+  f: &mut Frame<'_, B>,
   app: &mut App,
   area: Rect,
 ) {
@@ -588,7 +596,7 @@ fn draw_deployments_tab<B: Backend>(
   );
 }
 
-fn draw_deployments_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_deployments_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, DEPLOYMENTS_TITLE, "", app.data.deployments.items.len());
 
   draw_resource_block(
@@ -624,14 +632,14 @@ fn draw_deployments_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rec
         Cell::from(c.available.to_string()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
   );
 }
 
-fn draw_jobs_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_jobs_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   draw_resource_tab!(
     JOBS_TITLE,
     block,
@@ -644,7 +652,7 @@ fn draw_jobs_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App
   );
 }
 
-fn draw_jobs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_jobs_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, JOBS_TITLE, "", app.data.jobs.items.len());
 
   draw_resource_block(
@@ -671,7 +679,7 @@ fn draw_jobs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
         Cell::from(c.duration.to_string()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
@@ -680,7 +688,7 @@ fn draw_jobs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
 
 fn draw_daemon_sets_tab<B: Backend>(
   block: ActiveBlock,
-  f: &mut Frame<B>,
+  f: &mut Frame<'_, B>,
   app: &mut App,
   area: Rect,
 ) {
@@ -696,7 +704,7 @@ fn draw_daemon_sets_tab<B: Backend>(
   );
 }
 
-fn draw_daemon_sets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_daemon_sets_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, DAEMON_SETS_TITLE, "", app.data.daemon_sets.items.len());
 
   draw_resource_block(
@@ -738,14 +746,19 @@ fn draw_daemon_sets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rec
         Cell::from(c.available.to_string()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
   );
 }
 
-fn draw_cronjobs_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_cronjobs_tab<B: Backend>(
+  block: ActiveBlock,
+  f: &mut Frame<'_, B>,
+  app: &mut App,
+  area: Rect,
+) {
   draw_resource_tab!(
     CRON_JOBS_TITLE,
     block,
@@ -758,7 +771,7 @@ fn draw_cronjobs_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut
   );
 }
 
-fn draw_cronjobs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_cronjobs_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, CRON_JOBS_TITLE, "", app.data.cronjobs.items.len());
 
   draw_resource_block(
@@ -797,14 +810,19 @@ fn draw_cronjobs_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect)
         Cell::from(c.active.to_string()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
   );
 }
 
-fn draw_secrets_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_secrets_tab<B: Backend>(
+  block: ActiveBlock,
+  f: &mut Frame<'_, B>,
+  app: &mut App,
+  area: Rect,
+) {
   draw_resource_tab!(
     SECRETS_TITLE,
     block,
@@ -817,7 +835,7 @@ fn draw_secrets_tab<B: Backend>(block: ActiveBlock, f: &mut Frame<B>, app: &mut
   );
 }
 
-fn draw_secrets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_secrets_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, SECRETS_TITLE, "", app.data.secrets.items.len());
 
   draw_resource_block(
@@ -844,7 +862,7 @@ fn draw_secrets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
         Cell::from(c.data.len().to_string()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
@@ -853,7 +871,7 @@ fn draw_secrets_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
 
 fn draw_replication_controllers_tab<B: Backend>(
   block: ActiveBlock,
-  f: &mut Frame<B>,
+  f: &mut Frame<'_, B>,
   app: &mut App,
   area: Rect,
 ) {
@@ -869,7 +887,7 @@ fn draw_replication_controllers_tab<B: Backend>(
   );
 }
 
-fn draw_replication_controllers_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_replication_controllers_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, RPL_CTRL_TITLE, "", app.data.rpl_ctrls.items.len());
 
   draw_resource_block(
@@ -914,7 +932,7 @@ fn draw_replication_controllers_block<B: Backend>(f: &mut Frame<B>, app: &mut Ap
         Cell::from(c.selector.to_owned()),
         Cell::from(c.age.to_owned()),
       ])
-      .style(style_primary())
+      .style(style_primary(app.light_theme))
     },
     app.light_theme,
     app.is_loading,
@@ -922,13 +940,18 @@ fn draw_replication_controllers_block<B: Backend>(f: &mut Frame<B>, app: &mut Ap
 }
 
 /// common for all resources
-fn draw_describe_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect, title: Spans) {
+fn draw_describe_block<B: Backend>(
+  f: &mut Frame<'_, B>,
+  app: &mut App,
+  area: Rect,
+  title: Spans<'_>,
+) {
   let block = layout_block_top_border(title);
 
   let txt = &app.data.describe_out.get_txt();
   if !txt.is_empty() {
     let mut txt = Text::from(txt.clone());
-    txt.patch_style(style_primary());
+    txt.patch_style(style_primary(app.light_theme));
 
     let paragraph = Paragraph::new(txt)
       .block(block)
@@ -936,7 +959,7 @@ fn draw_describe_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect,
       .scroll((app.data.describe_out.offset, 0));
     f.render_widget(paragraph, area);
   } else {
-    loading(f, block, area, app.is_loading);
+    loading(f, block, area, app.is_loading, app.light_theme);
   }
 }
 
@@ -952,7 +975,7 @@ struct ResourceTableProps<'a, T> {
 
 /// Draw a kubernetes resource overview tab
 fn draw_resource_block<'a, B, T, F>(
-  f: &mut Frame<B>,
+  f: &mut Frame<'_, B>,
   area: Rect,
   table_props: ResourceTableProps<'a, T>,
   row_cell_mapper: F,
@@ -982,15 +1005,15 @@ fn draw_resource_block<'a, B, T, F>(
 
     f.render_stateful_widget(table, area, &mut table_props.resource.state);
   } else {
-    loading(f, block, area, is_loading);
+    loading(f, block, area, is_loading, light_theme);
   }
 }
 
-fn get_resource_row_style(status: &str, ready: (i32, i32)) -> Style {
+fn get_resource_row_style(status: &str, ready: (i32, i32), light: bool) -> Style {
   if status == "Running" && ready.0 == ready.1 {
-    style_primary()
+    style_primary(light)
   } else if status == "Completed" {
-    style_success()
+    style_success(light)
   } else if [
     "ContainerCreating",
     "PodInitializing",
@@ -999,15 +1022,15 @@ fn get_resource_row_style(status: &str, ready: (i32, i32)) -> Style {
   ]
   .contains(&status)
   {
-    style_secondary()
+    style_secondary(light)
   } else {
-    style_failure()
+    style_failure(light)
   }
 }
 
 fn get_node_title<S: AsRef<str>>(app: &App, suffix: S) -> String {
   format!(
-    "{} [{}] {}",
+    " {} [{}] {}",
     NODES_TITLE,
     app.data.nodes.items.len(),
     suffix.as_ref()
@@ -1016,7 +1039,7 @@ fn get_node_title<S: AsRef<str>>(app: &App, suffix: S) -> String {
 
 fn get_resource_title<S: AsRef<str>>(app: &App, title: S, suffix: S, items_len: usize) -> String {
   format!(
-    "{} {}",
+    " {} {}",
     title_with_ns(
       title.as_ref(),
       app
@@ -1054,15 +1077,13 @@ fn get_describe_active<'a>(block: ActiveBlock) -> &'a str {
 
 #[cfg(test)]
 mod tests {
-  use tui::{
-    backend::TestBackend,
-    buffer::Buffer,
-    style::{Color, Modifier},
-    Terminal,
-  };
+  use tui::{backend::TestBackend, buffer::Buffer, style::Modifier, Terminal};
 
   use super::*;
-  use crate::app::pods::KubePod;
+  use crate::{
+    app::pods::KubePod,
+    ui::utils::{COLOR_CYAN, COLOR_RED, COLOR_WHITE, COLOR_YELLOW},
+  };
 
   #[test]
   fn test_draw_resource_tabs_block() {
@@ -1085,10 +1106,10 @@ mod tests {
       .unwrap();
 
     let mut expected = Buffer::with_lines(vec![
-        "┌Resources─────────────────────────────────────────────────────────────────────────────────────────┐",
+        "┌ Resources ───────────────────────────────────────────────────────────────────────────────────────┐",
         "│ Pods <1> │ Services <2> │ Nodes <3> │ ConfigMaps <4> │ StatefulSets <5> │ ReplicaSets <6> │ Deplo│",
         "│                                                                                                  │",
-        "│Pods (ns: all) [1] | Containers <enter> | describe <d> | yaml <y>─────────────────────────────────│",
+        "│ Pods (ns: all) [1] | Containers <enter> | describe <d> | yaml <y> ───────────────────────────────│",
         "│   Namespace                Name                               Ready     Status    Restarts  A    │",
         "│=> pod namespace test       pod name test                      0/2       Failed    0         6    │",
         "└──────────────────────────────────────────────────────────────────────────────────────────────────┘",
@@ -1097,15 +1118,15 @@ mod tests {
     // First row heading style
     for col in 0..=99 {
       match col {
-        0 | 10..=99 => {
+        0 | 12..=99 => {
           expected
             .get_mut(col, 0)
-            .set_style(Style::default().fg(Color::Yellow));
+            .set_style(Style::default().fg(COLOR_YELLOW));
         }
         _ => {
           expected.get_mut(col, 0).set_style(
             Style::default()
-              .fg(Color::Yellow)
+              .fg(COLOR_YELLOW)
               .add_modifier(Modifier::BOLD),
           );
         }
@@ -1117,12 +1138,12 @@ mod tests {
         0..=12 | 25..=27 | 37..=39 | 54..=56 | 73..=75 | 91..=93 | 99 => {
           expected
             .get_mut(col, 1)
-            .set_style(Style::default().fg(Color::Yellow));
+            .set_style(Style::default().fg(COLOR_YELLOW));
         }
         _ => {
           expected
             .get_mut(col, 1)
-            .set_style(Style::default().fg(Color::White));
+            .set_style(Style::default().fg(COLOR_WHITE));
         }
       }
     }
@@ -1130,28 +1151,28 @@ mod tests {
     for col in 0..=99 {
       expected
         .get_mut(col, 2)
-        .set_style(Style::default().fg(Color::Yellow));
+        .set_style(Style::default().fg(COLOR_YELLOW));
     }
 
     // fourth row tab header style
     for col in 0..=99 {
       match col {
-        0 | 66..=99 => {
+        0 | 68..=99 => {
           expected
             .get_mut(col, 3)
-            .set_style(Style::default().fg(Color::Yellow));
+            .set_style(Style::default().fg(COLOR_YELLOW));
         }
-        1..=19 => {
+        1..=20 => {
           expected.get_mut(col, 3).set_style(
             Style::default()
-              .fg(Color::Yellow)
+              .fg(COLOR_YELLOW)
               .add_modifier(Modifier::BOLD),
           );
         }
         _ => {
           expected.get_mut(col, 3).set_style(
             Style::default()
-              .fg(Color::White)
+              .fg(COLOR_WHITE)
               .add_modifier(Modifier::BOLD),
           );
         }
@@ -1163,12 +1184,12 @@ mod tests {
         1..=98 => {
           expected
             .get_mut(col, 4)
-            .set_style(Style::default().fg(Color::White));
+            .set_style(Style::default().fg(COLOR_WHITE));
         }
         _ => {
           expected
             .get_mut(col, 4)
-            .set_style(Style::default().fg(Color::Yellow));
+            .set_style(Style::default().fg(COLOR_YELLOW));
         }
       }
     }
@@ -1178,14 +1199,14 @@ mod tests {
         1..=98 => {
           expected.get_mut(col, 5).set_style(
             Style::default()
-              .fg(Color::Red)
+              .fg(COLOR_RED)
               .add_modifier(Modifier::REVERSED),
           );
         }
         _ => {
           expected
             .get_mut(col, 5)
-            .set_style(Style::default().fg(Color::Yellow));
+            .set_style(Style::default().fg(COLOR_YELLOW));
         }
       }
     }
@@ -1194,7 +1215,7 @@ mod tests {
     for col in 0..=99 {
       expected
         .get_mut(col, 6)
-        .set_style(Style::default().fg(Color::Yellow));
+        .set_style(Style::default().fg(COLOR_YELLOW));
     }
 
     terminal.backend().assert_buffer(&expected);
@@ -1257,7 +1278,7 @@ mod tests {
               Cell::from(c.data.to_string()),
               Cell::from(c.age.to_owned()),
             ])
-            .style(style_primary())
+            .style(style_primary(false))
           },
           false,
           false,
@@ -1280,14 +1301,14 @@ mod tests {
         0..=3 => {
           expected.get_mut(col, 0).set_style(
             Style::default()
-              .fg(Color::Yellow)
+              .fg(COLOR_YELLOW)
               .add_modifier(Modifier::BOLD),
           );
         }
         4..=14 => {
           expected.get_mut(col, 0).set_style(
             Style::default()
-              .fg(Color::White)
+              .fg(COLOR_WHITE)
               .add_modifier(Modifier::BOLD),
           );
         }
@@ -1299,13 +1320,13 @@ mod tests {
     for col in 0..=99 {
       expected
         .get_mut(col, 1)
-        .set_style(Style::default().fg(Color::White));
+        .set_style(Style::default().fg(COLOR_WHITE));
     }
     // first table data row style
     for col in 0..=99 {
       expected.get_mut(col, 2).set_style(
         Style::default()
-          .fg(Color::Cyan)
+          .fg(COLOR_CYAN)
           .add_modifier(Modifier::REVERSED),
       );
     }
@@ -1314,7 +1335,7 @@ mod tests {
       for col in 0..=99 {
         expected
           .get_mut(col, row)
-          .set_style(Style::default().fg(Color::Cyan));
+          .set_style(Style::default().fg(COLOR_CYAN));
       }
     }
 
@@ -1324,7 +1345,7 @@ mod tests {
   #[test]
   fn test_get_node_title() {
     let app = App::default();
-    assert_eq!(get_node_title(&app, "-> hello"), "Nodes [0] -> hello");
+    assert_eq!(get_node_title(&app, "-> hello"), " Nodes [0] -> hello");
   }
 
   #[test]
@@ -1332,7 +1353,7 @@ mod tests {
     let app = App::default();
     assert_eq!(
       get_resource_title(&app, "Title", "-> hello", 5),
-      "Title (ns: all) [5] -> hello"
+      " Title (ns: all) [5] -> hello"
     );
   }
 
@@ -1341,7 +1362,7 @@ mod tests {
     let app = App::default();
     assert_eq!(
       get_container_title(&app, 3, "hello"),
-      "Pods (ns: all) [0] -> Containers [3] hello"
+      " Pods (ns: all) [0] -> Containers [3] hello"
     );
   }
 
